@@ -118,11 +118,11 @@ CatalogView::CatalogView(QWidget* parent, Catalog* catalog)
     m_browser->setRootIsDecorated(false);
     m_browser->setAllColumnsShowFocus(true);
     m_browser->setAlternatingRowColors(true);
-    m_browser->viewport()->setBackgroundRole(QPalette::Background);
+    m_browser->viewport()->setBackgroundRole(QPalette::Window);
 #ifdef Q_OS_DARWIN
     QPalette p;
-    p.setColor(QPalette::AlternateBase, p.color(QPalette::Background).darker(110));
-    p.setColor(QPalette::Highlight, p.color(QPalette::Background).darker(150));
+    p.setColor(QPalette::AlternateBase, p.color(QPalette::Window).darker(110));
+    p.setColor(QPalette::Highlight, p.color(QPalette::Window).darker(150));
     m_browser->setPalette(p);
 #endif
 
@@ -226,6 +226,7 @@ void CatalogView::fillFilterOptionsMenu()
     QMenu* allmenus[2] = {basicMenu, extMenu};
     QMenu* columnsMenu = m_filterOptionsMenu->addMenu(i18nc("@title:inmenu", "Searchable column"));
 
+    QActionGroup* columnsMenuGroup = new QActionGroup(columnsMenu);
     QAction* txt;
     txt = m_filterOptionsMenu->addAction(i18nc("@title:inmenu", "Resort and refilter on content change"), m_proxyModel, &CatalogTreeFilterModel::setDynamicSortFilter);
     txt->setCheckable(true);
@@ -243,13 +244,13 @@ void CatalogView::fillFilterOptionsMenu()
     }
     if (!extStates)
         m_filterOptionsMenu->addSeparator();
-    for (int i = -1; i < CatalogTreeModel::DisplayedColumnCount; ++i) {
-        qCWarning(LOKALIZE_LOG) << i;
+    for (int i = -1; i < CatalogTreeModel::DisplayedColumnCount-1; ++i) {
         txt = columnsMenu->addAction((i == -1) ? i18nc("@item:inmenu all columns", "All") :
                                      m_model->headerData(i, Qt::Horizontal, Qt::DisplayRole).toString());
         txt->setData(-i - 2);
         txt->setCheckable(true);
         txt->setChecked(m_proxyModel->filterKeyColumn() == i);
+        txt->setActionGroup(columnsMenuGroup);
     }
     refreshCurrentIndex();
 }
