@@ -33,6 +33,9 @@
 #include "prefs.h"
 #include "project.h"
 #include "completionstorage.h"
+#include "languagetoolmanager.h"
+#include "languagetoolresultjob.h"
+#include "languagetoolparser.h"
 
 #include <klocalizedstring.h>
 #include <kcompletionbox.h>
@@ -50,7 +53,9 @@
 #include <QMouseEvent>
 #include <QToolTip>
 #include <QScrollBar>
-
+#include <QElapsedTimer>
+#include <QJsonDocument>
+#include <QJsonObject>
 
 inline static QImage generateImage(const QString& str, const QFont& font)
 {
@@ -163,15 +168,22 @@ void TranslationUnitTextEdit::fileLoaded()
     QLocale langLocale(langCode);
     // First try to use a locale name derived from the language code
     m_highlighter->setCurrentLanguage(langLocale.name());
+    //qCWarning(LOKALIZE_LOG) << "Attempting to set highlighting for " << m_part << " as " << langLocale.name();
     // If that fails, try to use the language code directly
     if (m_highlighter->currentLanguage() != langLocale.name() || m_highlighter->currentLanguage().isEmpty()) {
         m_highlighter->setCurrentLanguage(langCode);
+        //qCWarning(LOKALIZE_LOG) << "Attempting to set highlighting for " << m_part << " as " << langCode;
         if (m_highlighter->currentLanguage() != langCode && langCode.length() > 2)
+        {
             m_highlighter->setCurrentLanguage(langCode.left(2));
+            //qCWarning(LOKALIZE_LOG) << "Attempting to set highlighting for " << m_part << " as " << langCode.left(2);
+        }
     }
+    //qCWarning(LOKALIZE_LOG) << "Spellchecker found "<<m_highlighter->spellCheckerFound()<< " as "<<m_highlighter->currentLanguage();
+    //setSpellCheckingLanguage(m_highlighter->currentLanguage());
     //"i use an english locale while translating kde pot files from english to hebrew" Bug #181989
     Qt::LayoutDirection targetLanguageDirection = Qt::LeftToRight;
-    static QLocale::Language rtlLanguages[] = {QLocale::Arabic, QLocale::Hebrew, QLocale::Urdu, QLocale::Persian, QLocale::Pashto};
+    static const QLocale::Language rtlLanguages[] = {QLocale::Arabic, QLocale::Hebrew, QLocale::Urdu, QLocale::Persian, QLocale::Pashto};
     int i = sizeof(rtlLanguages) / sizeof(QLocale::Arabic);
     while (--i >= 0 && langLocale.language() != rtlLanguages[i])
         ;
@@ -183,7 +195,7 @@ void TranslationUnitTextEdit::fileLoaded()
         return;
 
     //"Some language do not need space between words. For example Chinese."
-    static QLocale::Language noSpaceLanguages[] = {QLocale::Chinese};
+    static const QLocale::Language noSpaceLanguages[] = {QLocale::Chinese};
     i = sizeof(noSpaceLanguages) / sizeof(QLocale::Chinese);
     while (--i >= 0 && langLocale.language() != noSpaceLanguages[i])
         ;
@@ -1019,33 +1031,51 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
 //     QAction* spellchecking=menu.addAction();
 //     event->accept();
     }
+    void TranslationUnitTextEdit::zoomRequestedSlot(qreal fontSize)
+    {
+        QFont curFont = font();
+        curFont.setPointSizeF(fontSize);
+        setFont(curFont);
+    }
 
     void TranslationUnitTextEdit::wheelEvent(QWheelEvent * event) {
         //Override default KTextEdit behavior which ignores Ctrl+wheelEvent when the field is not ReadOnly (i/o zooming)
         if (m_part == DocPosition::Target && !Settings::mouseWheelGo() && (event->modifiers() == Qt::ControlModifier)) {
             float delta = event->angleDelta().y() / 120.f;
             zoomInF(delta);
+            //Also zoom in the source
+            emit zoomRequested(font().pointSizeF());
             return;
         }
 
         if (m_part == DocPosition::Source || !Settings::mouseWheelGo())
+        {
+            if (event->modifiers() == Qt::ControlModifier)
+            {
+                float delta = event->angleDelta().y() / 120.f;
+                zoomInF(delta);
+                //Also zoom in the target
+                emit zoomRequested(font().pointSizeF());
+                return;
+            }
             return KTextEdit::wheelEvent(event);
+        }
 
         switch (event->modifiers()) {
         case Qt::ControlModifier:
-            if (event->delta() > 0)
+            if (event->angleDelta().y() > 0)
                 emit gotoPrevFuzzyRequested();
             else
                 emit gotoNextFuzzyRequested();
             break;
         case Qt::AltModifier:
-            if (event->delta() > 0)
+            if (event->angleDelta().y() > 0)
                 emit gotoPrevUntranslatedRequested();
             else
                 emit gotoNextUntranslatedRequested();
             break;
         case Qt::ControlModifier + Qt::ShiftModifier:
-            if (event->delta() > 0)
+            if (event->angleDelta().y() > 0)
                 emit gotoPrevFuzzyUntrRequested();
             else
                 emit gotoNextFuzzyUntrRequested();
@@ -1053,7 +1083,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         case Qt::ShiftModifier:
             return KTextEdit::wheelEvent(event);
         default:
-            if (event->delta() > 0)
+            if (event->angleDelta().y() > 0)
                 emit gotoPrevRequested();
             else
                 emit gotoNextRequested();
@@ -1097,6 +1127,8 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             QString tip;
 
             QString langCode = m_highlighter->currentLanguage();
+
+            //qCWarning(LOKALIZE_LOG) << "Spellchecker found "<<m_highlighter->spellCheckerFound()<< " as "<<m_highlighter->currentLanguage();
             bool nospell = langCode.isEmpty();
             if (nospell)
                 langCode = m_part == DocPosition::Source ? m_catalog->sourceLangCode() : m_catalog->targetLangCode();
@@ -1111,8 +1143,29 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         return KTextEdit::event(event);
     }
 
+    void TranslationUnitTextEdit::slotLanguageToolFinished(const QString &result)
+    {
+        LanguageToolParser parser;
+        const QJsonDocument doc = QJsonDocument::fromJson(result.toUtf8());
+        const QJsonObject fields = doc.object();
+        emit languageToolChanged(parser.parseResult(fields, toPlainText()));
+    }
 
+    void TranslationUnitTextEdit::slotLanguageToolError(const QString &str)
+    {        
+        emit languageToolChanged(i18n("An error was reported: %1", str));
+    }
 
+    void TranslationUnitTextEdit::launchLanguageTool()     {
+        LanguageToolResultJob *job = new LanguageToolResultJob(this);
+        job->setUrl(LanguageToolManager::self()->languageToolCheckPath());
+        job->setNetworkAccessManager(LanguageToolManager::self()->networkAccessManager());
+        job->setText(toPlainText());
+        job->setLanguage(m_catalog->targetLangCode());
+        connect(job, &LanguageToolResultJob::finished, this, &TranslationUnitTextEdit::slotLanguageToolFinished);
+        connect(job, &LanguageToolResultJob::error, this, &TranslationUnitTextEdit::slotLanguageToolError);
+        job->start();
+    }
     void TranslationUnitTextEdit::tagMenu()     {
         doTag(false);
     }
@@ -1286,7 +1339,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             m_completionBox->resize(m_completionBox->sizeHint());
             QPoint p = cursorRect().bottomRight();
             if (p.x() < 10) //workaround Qt bug
-                p.rx() += textCursor().verticalMovementX() + QFontMetrics(currentFont()).width('W');
+                p.rx() += textCursor().verticalMovementX() + QFontMetrics(currentFont()).horizontalAdvance('W');
             m_completionBox->move(viewport()->mapToGlobal(p));
         } else
             m_completionBox->hide();
