@@ -78,10 +78,12 @@ public slots:
     void tagImmediate();
     void insertTag(InlineTag tag);
     void spellReplace();
+    void launchLanguageTool();
 
     void emitCursorPositionChanged();//for leds
 
     void doExplicitCompletion();
+    void zoomRequestedSlot(qreal fontSize);
 
 protected:
     void keyPressEvent(QKeyEvent *keyEvent) override;
@@ -114,6 +116,9 @@ private slots:
     void completionActivated(const QString&);
     void fileLoaded();
 
+    void slotLanguageToolFinished(const QString &result);
+    void slotLanguageToolError(const QString &str);
+
 signals:
     void toggleApprovementRequested();
     void undoRequested();
@@ -132,11 +137,13 @@ signals:
     void gotoPrevFuzzyUntrRequested();
     void gotoNextFuzzyUntrRequested();
     void gotoEntryRequested(const DocPosition&);
+    void zoomRequested(qreal);
 
 
     void tagInsertRequested(const InlineTag& tag);
 
     void binaryUnitSelectRequested(const QString&);
+    void languageToolChanged(const QString&);
     void tmLookupRequested(DocPosition::Part, const QString&);
 
     void contentsModified(const DocPosition&);
